require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_softwareinstall',
  dscmeta_resource_friendly_name: 'SoftwareInstall',
  dscmeta_resource_name: 'DSC_SoftwareInstallResource',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SoftwareInstallDsc',
  dscmeta_module_version: '0.6',
  docs: 'The DSC SoftwareInstall resource type.
         Automatically generated from version 0.6',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_requirevalidsignature: {
      type: 'Optional[Boolean]',
      desc: 'Requite valid signing certificate on the installer. Implied TRUE if Subject or Thumbprint are validated.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_runascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Specifies the credential to use when running the installer.',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_uninstallrequiresinstaller: {
      type: 'Optional[Boolean]',
      desc: 'Installer is required for uninstall command. Keeps cached files, or downloads installer if cache is missing.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_usedefaultcredential: {
      type: 'Optional[Boolean]',
      desc: 'Specifies to use the Default Credential to send the request.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_thumbprint: {
      type: 'Optional[String]',
      desc: 'Thumbprint of the signing certificate used for installer. Wildcards are supported.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'String',
      desc: 'Name of the software to be installed. Should match name in Add/Remove Programs. Wildcards are supported.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ignorereboot: {
      type: 'Optional[Boolean]',
      desc: 'Specifies that we will not instruct DSC to trigger a reboot on exit code 3010.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_versioncomparison: {
      type: "Optional[Enum['Any', 'LessThan', 'LessThanOrEqualTo', 'EqualTo', 'GreaterThanOrEqualTo', 'GreaterThan']]",
      desc: 'How the version is compared to the installed version. Defaults to EqualTo.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_version: {
      type: 'Optional[String]',
      desc: 'Version of the software to be installed. Should match value in Add/Remove Programs.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_uri: {
      type: 'String',
      desc: 'Uri of a file which should be copied or downloaded. This parameter supports HTTP, HTTPS, FTP, and FILE values.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_proxyusedefaultcredential: {
      type: 'Optional[Boolean]',
      desc: 'Specifies to use the Default Credential to access the proxy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_installcommand: {
      type: 'Optional[String]',
      desc: 'Install command for software package. The following string replacements will be performed: {0} = Installer File, {1} = Log File, {2} = Package Id (as detected in Uninstall entry).',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Specifies a user account that has permission to send the request.',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_subject: {
      type: 'Optional[String]',
      desc: 'Subject name of signing certificate used for installer. Wildcards are supported.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_type: {
      type: "Enum['MSI', 'EXE']",
      desc: 'Type of installer package.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_uninstallcommand: {
      type: 'Optional[String]',
      desc: 'Uninstall command for software package. The following string replacements will be performed: {0} = Installer File, {1} = Log File, {2} = Package Id (as detected in Uninstall entry).',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Says whether DestinationPath exists on the machine.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_proxy: {
      type: 'Optional[String]',
      desc: 'Specifies the proxy to use when sending the request.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_servercertificatevalidationcallback: {
      type: 'Optional[String]',
      desc: 'Callback scriptblock used to validate server certificate of server when downloading over HTTPS or FTPS.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_uninstallreturncode: {
      type: 'Optional[Array[Integer[0, 4294967295]]]',
      desc: 'Valid return codes for the uninstall command. Default is 0 and 3010.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32[]',
      mof_is_embedded: false,
    },
    dsc_algorithm: {
      type: "Optional[Enum['None', 'SHA1', 'SHA256', 'SHA384', 'SHA512', 'MACTripleDES', 'MD5', 'RIPEMD160']]",
      desc: 'Specifies the checksum type to verify the downloaded file',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_timeoutseconds: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies how long the request can be pending before it times out.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_proxycredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Specifies a user account that has permission to access the proxy.',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_publisher: {
      type: 'Optional[String]',
      desc: 'Name of the publisher of the software to be installed. Should match value in Add/Remove Programs. Wildcards are supported.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_logpath: {
      type: 'Optional[String]',
      desc: 'Specifies path to log file.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_returncode: {
      type: 'Optional[Array[Integer[0, 4294967295]]]',
      desc: 'Valid return codes for the install command. Default is 0, 1641, and 3010.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32[]',
      mof_is_embedded: false,
    },
    dsc_hash: {
      type: 'Optional[String]',
      desc: 'Specifies the checksum value to compare against the downloaded file.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
